==> haskell-unbounded-delays-0.1.1.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.1.0
id: unbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN
key: unbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN
license: BSD-3-Clause
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
abi: d89abf3e7f33657aef9fe79bbcf07dc2
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
import-dirs: /usr/lib/ghc-8.4.3/site-local/unbounded-delays-0.1.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unbounded-delays-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unbounded-delays-0.1.1.0
hs-libraries: HSunbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unbounded-delays-0.1.1.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.1.0
id: unbounded-delays-0.1.1.0-7ulHERuvlgAKyhaTH4vNZc
key: unbounded-delays-0.1.1.0-7ulHERuvlgAKyhaTH4vNZc
license: BSD-3-Clause
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
abi: e73a732286070190f2d0e79b28aa8d35
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
import-dirs: /usr/lib/ghc-8.6.1/site-local/unbounded-delays-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/unbounded-delays-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/unbounded-delays-0.1.1.0
hs-libraries: HSunbounded-delays-0.1.1.0-7ulHERuvlgAKyhaTH4vNZc
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
